@@ -1,6 +1,6 @@
 """
-LEGION (https://gotham-security.com)
-Copyright (c) 2023 Gotham Security
+LEGION (https://shanewilliamscott.com)
+Copyright (c) 2025 Shane William Scott
 
     This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public
     License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later
@@ -12,6 +12,8 @@ Copyright (c) 2023 Gotham Security
 
     You should have received a copy of the GNU General Public License along with this program.
     If not, see <http://www.gnu.org/licenses/>.
+
+Author(s): Shane Scott (sscott@shanewilliamscott.com), Dmitriy Dubson (d.dubson@gmail.com)
 """
 
 import os
@@ -22,7 +24,7 @@ warnings.filterwarnings("ignore", category=UserWarning)
 from PyQt6 import QtCore
 
 from app.logging.legionLog import getAppLogger
-from app.http.isHttps import isHttps
+from app.httputil.isHttps import isHttps
 from app.timing import getTimestamp
 from app.auxiliary import isKali
 
@@ -71,7 +73,8 @@ class Screenshooter(QtCore.QThread):
 
         self.processing = False
 
-        if not len(self.queue) == 0:  # if meanwhile queue were added to the queue, start over unless we are in pause mode
+        if not len(self.queue) == 0:
+            # if meanwhile queue were added to the queue, start over unless we are in pause mode
             self.run()
 
     def save(self, url, ip, port, outputfile):
@@ -86,26 +89,70 @@ class Screenshooter(QtCore.QThread):
 
         self.tsLog('Taking Screenshot of: {0}'.format(str(url)))
 
-        # Use eyewitness under Kali. Use webdriver is not Kali. Once eyewitness is more boradly available, the conter case can be eliminated.
+        # Use eyewitness under Kali.
+        # Use webdriver if not Kali.
+        # Once eyewitness is more broadly available, the counter case can be eliminated.
         if isKali():
-            import tempfile
-            import subprocess
-
-            tmpOutputfolder = tempfile.mkdtemp(dir=self.outputfolder)
-            command = ('xvfb-run --server-args="-screen 0:0, 1024x768x24" /usr/bin/eyewitness --single "{url}/"'
-                       ' --no-prompt -d "{outputfolder}"') \
-                      .format(url=url, outputfolder=tmpOutputfolder)
-            p = subprocess.Popen(command, shell=True)
-            p.wait()  # wait for command to finish
-            fileName = os.listdir(tmpOutputfolder + '/screens/')[0]
-            outputfile = tmpOutputfolder.removeprefix(self.outputfolder) + '/screens/' + fileName
+            eyewitness_path = "/usr/bin/eyewitness"
         else:
-            from selenium import webdriver
+            eyewitness_path = "/usr/local/bin/eyewitness"
 
-            driver = webdriver.PhantomJS(executable_path='/usr/bin/phantomjs')
-            driver.set_window_size(1280, 1024)
-            driver.get(url)
-            driver.save_screenshot('{0}/{1}'.format(self.outputfolder, outputfile))
-            driver.quit()
+        import tempfile
+        import subprocess
+
+        try:
+            tmpOutputfolder = tempfile.mkdtemp(dir=self.outputfolder)
+            if not os.path.isfile(eyewitness_path):
+                raise FileNotFoundError("EyeWitness not found at /usr/bin/eyewitness. Please install it.")
+
+            command = (
+                'xvfb-run -a {eyewitness} --single {url} --no-prompt --web --delay 5 -d {outputfolder}'
+            ).format(
+                eyewitness=eyewitness_path,
+                url=url,
+                outputfolder=tmpOutputfolder
+            )
+            self.tsLog(f'Executing: {command}')
+            # Flake8: break up long command string if needed
+            p = subprocess.Popen(command, shell=True, stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL)
+            p.wait()  # wait for command to finish
+
+            screens_dir = os.path.join(tmpOutputfolder, 'screens')
+            if not os.path.isdir(screens_dir):
+                raise FileNotFoundError(f"EyeWitness did not create expected directory: {screens_dir}")
+
+            files = [f for f in os.listdir(screens_dir) if f.lower().endswith('.png')]
+            if not files:
+                raise FileNotFoundError(f"No screenshot PNG found in {screens_dir}. EyeWitness may have failed.")
+
+            fileName = files[0]
+            # Remove prefix in a way compatible with all Python versions
+            if tmpOutputfolder.startswith(self.outputfolder):
+                rel_tmp = tmpOutputfolder[len(self.outputfolder):].lstrip(os.sep)
+            else:
+                rel_tmp = tmpOutputfolder
+            outputfile = os.path.join(rel_tmp, 'screens', fileName)
+            # Normalize for DB/UI
+            normalized_outputfile = outputfile.replace("\\", "/")
+            outputfile = normalized_outputfile
+
+            # Copy/rename to deterministic filename for deduplication
+            deterministic_name = f"{ip}-{port}-screenshot.png"
+            deterministic_path = os.path.join(self.outputfolder, deterministic_name)
+            try:
+                import shutil
+                src_path = os.path.join(tmpOutputfolder, 'screens', fileName)
+                shutil.copy2(src_path, deterministic_path)
+                self.tsLog(
+                f"Copied screenshot to deterministic filename: {deterministic_path}"
+            )
+            except Exception as e:
+                self.tsLog(f"Failed to copy screenshot to deterministic filename: {e}")
+
+        except Exception as e:
+            self.tsLog(f"EyeWitness screenshot failed: {e}")
+            self.done.emit(ip, port, "")
+            return
+        
         self.tsLog('Saving screenshot as: {0}'.format(str(outputfile)))
         self.done.emit(ip, port, outputfile)  # send a signal to add the 'process' to the DB
