@@ -1,6 +1,6 @@
 """
-LEGION (https://gotham-security.com)
-Copyright (c) 2023 Gotham Security
+LEGION (https://shanewilliamscott.com)
+Copyright (c) 2025 Shane William Scott
 
     This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public
     License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later
@@ -13,7 +13,7 @@ Copyright (c) 2023 Gotham Security
     You should have received a copy of the GNU General Public License along with this program.
     If not, see <http://www.gnu.org/licenses/>.
 
-Author(s): Shane Scott (sscott@gotham-security.com), Dmitriy Dubson (d.dubson@gmail.com)
+Author(s): Shane Scott (sscott@shanewilliamscott.com), Dmitriy Dubson (d.dubson@gmail.com)
 """
 
 from app.auxiliary import Filters
@@ -39,9 +39,14 @@ class HostRepository:
         query = 'SELECT * FROM hostObj AS hosts WHERE 1=1'
         query += applyHostsFilters(filters)
         query = text(query)
-        result = session.execute(query).fetchall()
+        result = session.execute(query)
+        rows = result.fetchall()
+        # Get column names from result metadata
+        keys = result.keys()
+        # Convert each row (tuple) to a dict
+        hosts = [dict(zip(keys, row)) for row in rows]
         session.close()
-        return result
+        return hosts
 
     def getHostsAndPortsByServiceName(self, service_name, filters: Filters):
         session = self.dbAdapter.session()
@@ -53,9 +58,12 @@ class HostRepository:
                  "WHERE services.name=:service_name")
         query += applyFilters(filters)
         query = text(query)
-        result = session.execute(query, {'service_name': str(service_name)}).fetchall()
+        result = session.execute(query, {'service_name': str(service_name)})
+        rows = result.fetchall()
+        keys = result.keys()
+        services = [dict(zip(keys, row)) for row in rows]
         session.close()
-        return result
+        return services
 
     def getHostInformation(self, host_ip_address: str):
         session = self.dbAdapter.session()
@@ -82,3 +90,21 @@ class HostRepository:
             session.add(host)
             session.commit()
         session.close()
+
+    def getHostByIP(self, ip):
+        """
+        Return the hostObj for a given IP address, or None if not found.
+        """
+        session = self.dbAdapter.session()
+        host = session.query(hostObj).filter_by(ip=str(ip)).first()
+        session.close()
+        return host
+
+    def getAllHostObjs(self):
+        """
+        Return all hostObj ORM objects in the database.
+        """
+        session = self.dbAdapter.session()
+        hosts = session.query(hostObj).all()
+        session.close()
+        return hosts
