@@ -1,6 +1,6 @@
 """
-LEGION (https://gotham-security.com)
-Copyright (c) 2023 Gotham Security
+LEGION (https://shanewilliamscott.com)
+Copyright (c) 2025 Shane William Scott
 
     This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public
     License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later
@@ -13,7 +13,7 @@ Copyright (c) 2023 Gotham Security
     You should have received a copy of the GNU General Public License along with this program.
     If not, see <http://www.gnu.org/licenses/>.
 
-Author(s): Shane Scott (sscott@gotham-security.com), Dmitriy Dubson (d.dubson@gmail.com)
+Author(s): Shane Scott (sscott@shanewilliamscott.com), Dmitriy Dubson (d.dubson@gmail.com)
 """
 
 from typing import Union
@@ -38,23 +38,28 @@ class ProcessRepository:
     # we are using the same model to display process information everywhere)
 
     def getProcesses(self, filters, showProcesses: Union[str, bool] = 'noNmap', sort: str = 'desc', ncol: str = 'id'):
-        # we do not fetch nmap processes because these are not displayed in the host tool tabs / tools
+        # Modified: include nmap processes in the tools table
         session = self.dbAdapter.session()
         if showProcesses == 'noNmap':
             query = text('SELECT "0", "0", "0", process.name, "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0" '
-                         'FROM process AS process WHERE process.closed = "False" AND process.name != "nmap" '
-                         'GROUP BY process.name')
-            result = session.execute(query).fetchall()
+                         'FROM process AS process WHERE process.closed = "False" '
+                         'ORDER BY process.id DESC')
+            result = session.execute(query)
         elif not showProcesses:
             query = text('SELECT process.id, process.hostIp, process.tabTitle, process.outputfile, output.output '
                          'FROM process AS process INNER JOIN process_output AS output ON process.id = output.processId '
                          'WHERE process.display = :display AND process.closed = "False" order by process.id desc')
-            result = session.execute(query, {'display': str(showProcesses)}).fetchall()
+            result = session.execute(query, {'display': str(showProcesses)})
         else:
-            query = text('SELECT * FROM process AS process WHERE process.display=:display order by {0} {1}'.format(ncol, sort))
-            result = session.execute(query, {'display': str(showProcesses)}).fetchall()
+            query = text(
+                'SELECT * FROM process AS process WHERE process.display=:display order by {0} {1}'.format(ncol, sort)
+            )
+            result = session.execute(query, {'display': str(showProcesses)})
+        rows = result.fetchall()
+        keys = result.keys()
+        processes = [dict(zip(keys, row)) for row in rows]
         session.close()
-        return result
+        return processes
 
     def storeProcess(self, proc):
         session = self.dbAdapter.session()
@@ -182,6 +187,16 @@ class ProcessRepository:
             session.add(proc)
             session.commit()
 
+    def storeProcessPercent(self, processId: str, percent):
+        """Update the percent field for a process."""
+        session = self.dbAdapter.session()
+        proc = session.query(process).filter_by(id=processId).first()
+        if proc:
+            proc.percent = percent
+            session.add(proc)
+            session.commit()
+        session.close()
+
     def storeCloseStatus(self, processId):
         session = self.dbAdapter.session()
         proc = session.query(process).filter_by(id=processId).first()
